/*   This is part of km-ViewOS
 *   The kernel-mode implementation of OSVIEW -- A Process with a View
 *
 *   kmview.h: generic definitions, not directly related to virtualization
 *   
 *   Copyright 2006 Ludovico Gardenghi
 *   
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License, version 2, as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License along
 *   with this program; if not, write to the Free Software Foundation, Inc.,
 *   51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA.
 *
 *   $Id: kmview-main.h 668 2009-05-30 15:08:31Z rd235 $
 *
 */

#include <config.h>

#define KMVIEW_NAME PACKAGE_NAME
#define KMVIEW_DESC "kmview: kernel-module implementation of View-OS"
#define KMVIEW_VERSION PACKAGE_VERSION

#define KMVIEW_URL "http://savannah.nongnu.org/projects/view-os"

#define KMVIEW_COPYRIGHT "2007 Renzo Davoli, University of Bologna, Italy"
#define KMVIEW_TEAM \
"P. Angelelli, A. Bacchelli, M. Belletti, P. Beverini, D. Billi, A. Forni,\n" \
"L. Gardenghi, A. Gasparini, D. Lacamera, C. Martellini, A. Seraghiti"
